This website requires JavaScript.
Explore
Help
Sign In
iHore
/
vLLM
Watch
8
Star
0
Fork
0
Code
Issues
Pull Requests
Actions
2
Packages
Projects
Releases
Wiki
Activity
Files
2fa1f8ec00cf85b15422cb4c0e8eb3632ee13ea8
vLLM
/
vllm
/
model_executor
/
layers
/
pooler
T
History
Wentao Ye
39a7f4f4e2
[Perf] Optimize
AllPool.forward
by slicing first, 51% faster in the method level benchmark (
#41163
)
...
Signed-off-by: yewentao256 <
zhyanwentao@126.com
>
2026-04-29 08:11:04 -07:00
..
seqwise
[MyPy] Enable mypy for
vllm/model_executor/layers/
(
#40159
)
2026-04-21 20:15:02 -07:00
tokwise
[Perf] Optimize
AllPool.forward
by slicing first, 51% faster in the method level benchmark (
#41163
)
2026-04-29 08:11:04 -07:00
__init__.py
[Model] Reorganize pooling layers (
#31973
)
2026-01-09 11:02:14 +00:00
abstract.py
[Model] Reorganize pooling layers (
#31973
)
2026-01-09 11:02:14 +00:00
activations.py
[Model] Deprecate the score task (this will not affect users). (
#37537
)
2026-03-20 08:07:56 +00:00
common.py
[Perf] Remove redundant device copies for CPU-only pooling token IDs, 48.9% E2E throughput improvement (
#38139
)
2026-03-29 18:12:50 +00:00
special.py
[Perf] Remove redundant device copies for CPU-only pooling token IDs, 48.9% E2E throughput improvement (
#38139
)
2026-03-29 18:12:50 +00:00